@@ -1,6 +1,7 @@
 from datetime import datetime as dt
 from datetime import timedelta as td
 from os import getenv
+from typing import Optional
 
 # libs
 from peewee import AutoField, TextField, ForeignKeyField, TimestampField
@@ -10,15 +11,51 @@ import psycopg2 as pg2
 import psycopg2.extras as pg2_extras
 
 # app
+from .wrappers import DataTable
 from .utils import notnull
 
-db = PostgresqlDatabase(
-	host=notnull(getenv('POSTGRES_HOST')),
-	port=notnull(getenv('POSTGRES_PORT')),
-	database=notnull(getenv('POSTGRES_DBNAME')),
-	user=notnull(getenv('POSTGRES_USER')),
-	password=notnull(getenv('POSTGRES_PASSWORD'))
-)
+db: Optional[PostgresqlDatabase] = None
+
+
+def init():
+	global db
+	if db: return
+
+	db = PostgresqlDatabase(
+		host=notnull(getenv('POSTGRES_HOST')),
+		port=notnull(getenv('POSTGRES_PORT')),
+		database=notnull(getenv('POSTGRES_DBNAME')),
+		user=notnull(getenv('POSTGRES_USER')),
+		password=notnull(getenv('POSTGRES_PASSWORD'))
+	)
+
+	# create schema if necessary
+	conn = pg2.connect(
+		host=notnull(getenv('POSTGRES_HOST')),
+		port=notnull(getenv('POSTGRES_PORT')),
+		dbname=notnull(getenv('POSTGRES_DBNAME')),
+		user=notnull(getenv('POSTGRES_USER')),
+		password=notnull(getenv('POSTGRES_PASSWORD'))
+	)
+	cur: pg2_extras.DictCursor = conn.cursor(cursor_factory=pg2_extras.DictCursor)
+	cur.execute('create schema if not exists core')
+	cur.execute('create schema if not exists data')
+	cur.execute('create schema if not exists geoplan')
+	conn.commit()
+	conn.close()
+
+	# connect and prepare tables
+	db.connect()
+	db.create_tables([User, Campaign, DataSource, CampaignDataSources, Supervisor, Participant, HourlyStats])
+
+	DataTable.con = pg2.connect(
+		database=notnull(getenv('POSTGRES_DBNAME')),
+		host=notnull(getenv('POSTGRES_HOST')),
+		port=notnull(getenv('POSTGRES_PORT')),
+		user=notnull(getenv('POSTGRES_USER')),
+		password=notnull(getenv('POSTGRES_PASSWORD')),
+		options="-c search_path=data"
+	)
 
 
 class User(Model):
@@ -115,22 +152,3 @@ class HourlyStats(Model):
 			(('participant', 'data_source'), False),  # selection by participant and/or data source
 			(('ts',), False),  # selection by timestamp
 		)
-
-
-# create schema if necessary
-conn = pg2.connect(
-	host=notnull(getenv('POSTGRES_HOST')),
-	port=notnull(getenv('POSTGRES_PORT')),
-	dbname=notnull(getenv('POSTGRES_DBNAME')),
-	user=notnull(getenv('POSTGRES_USER')),
-	password=notnull(getenv('POSTGRES_PASSWORD'))
-)
-cur: pg2_extras.DictCursor = conn.cursor(cursor_factory=pg2_extras.DictCursor)
-cur.execute('create schema if not exists core')
-cur.execute('create schema if not exists data')
-cur.execute('create schema if not exists geoplan')
-conn.commit()
-conn.close()
-# connect and prepare tables
-db.connect()
-db.create_tables([User, Campaign, DataSource, CampaignDataSources, Supervisor, Participant, HourlyStats])
